@@ -1,4 +1,3 @@
-import gettext
 from typing import Optional
 
 import click
@@ -10,31 +9,36 @@ from pulpcore.cli.ansible.context import (
 from pulpcore.cli.common.context import (
     EntityDefinition,
     EntityFieldDefinition,
+    PluginRequirement,
     PulpContext,
     pass_entity_context,
     pass_pulp_context,
 )
 from pulpcore.cli.common.generic import (
+    base_path_contains_option,
+    base_path_option,
     create_command,
     destroy_command,
     href_option,
+    label_command,
     label_select_option,
     list_command,
     name_option,
+    resource_option,
     show_command,
 )
+from pulpcore.cli.common.i18n import get_translation
 
-_ = gettext.gettext
+translation = get_translation(__name__)
+_ = translation.gettext
 
 
-def _repository_callback(
-    ctx: click.Context, param: click.Parameter, value: Optional[str]
-) -> EntityFieldDefinition:
-    # Pass None and "" verbatim
-    if value:
-        pulp_ctx: PulpContext = ctx.find_object(PulpContext)
-        return PulpAnsibleRepositoryContext(pulp_ctx, entity={"name": value})
-    return value
+repository_option = resource_option(
+    "--repository",
+    default_plugin="ansible",
+    default_type="ansible",
+    context_table={"ansible:ansible": PulpAnsibleRepositoryContext},
+)
 
 
 @click.group()
@@ -54,6 +58,7 @@ def distribution(ctx: click.Context, pulp_ctx: PulpContext, distribution_type: s
         raise NotImplementedError()
 
 
+filter_options = [label_select_option, base_path_option, base_path_contains_option]
 lookup_options = [href_option, name_option]
 create_options = [
     click.option("--name", required=True),
@@ -62,20 +67,22 @@ create_options = [
         required=True,
         help=_("the base (relative) path component of the published url."),
     ),
-    click.option(
-        "--repository",
-        required=True,
-        callback=_repository_callback,
-        help=_("repository with content to distribute"),
-    ),
+    repository_option,
     click.option(
         "--version", type=int, help=_("a repository version number, leave blank for latest")
     ),
 ]
-distribution.add_command(list_command(decorators=[label_select_option]))
+distribution.add_command(list_command(decorators=filter_options))
 distribution.add_command(show_command(decorators=lookup_options))
 distribution.add_command(destroy_command(decorators=lookup_options))
 distribution.add_command(create_command(decorators=create_options))
+distribution.add_command(
+    label_command(
+        need_plugins=[
+            PluginRequirement("ansible", "0.8.0.dev"),
+        ]
+    )
+)
 
 
 # TODO Add content_guard option
@@ -136,7 +143,9 @@ def update(
             body["repository_version"] = f"{repository_href}versions/{version}/"
         else:
             raise click.ClickException(
-                f"Distribution {name} doesn't have a repository set, "
-                f"please specify the repository to use  with --repository"
+                _(
+                    "Distribution {name} doesn't have a repository set, "
+                    "please specify the repository to use  with --repository"
+                ).format(name=name)
             )
     distribution_ctx.update(href, body=body)
