@@ -1,4 +1,3 @@
-import gettext
 from typing import Any, Optional, Union
 
 import click
@@ -10,6 +9,8 @@ from pulpcore.cli.ansible.context import (
 )
 from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.common.generic import (
+    common_remote_create_options,
+    common_remote_update_options,
     create_command,
     destroy_command,
     href_option,
@@ -17,27 +18,29 @@ from pulpcore.cli.common.generic import (
     label_select_option,
     list_command,
     name_option,
+    pulp_group,
+    pulp_option,
     show_command,
     update_command,
 )
+from pulpcore.cli.common.i18n import get_translation
 
-_ = gettext.gettext
+translation = get_translation(__name__)
+_ = translation.gettext
 
 
 def _requirements_callback(
     ctx: click.Context, param: click.Parameter, value: Any
 ) -> Optional[Union[str, Any]]:
     if value:
-        if isinstance(ctx.obj, PulpAnsibleRoleRemoteContext):
-            raise click.ClickException(f"Option {param.name} not valid for Role remote, see --help")
-        if param.name == "requirements-file":
+        if param.name == "requirements_file":
             return f"{yaml.safe_load(value)}"
         elif param.name == "requirements":
             return yaml.safe_load(f'"{value}"')
     return value
 
 
-@click.group()
+@pulp_group()
 @click.option(
     "-t",
     "--type",
@@ -57,76 +60,45 @@ def remote(ctx: click.Context, pulp_ctx: PulpContext, remote_type: str) -> None:
         raise NotImplementedError()
 
 
+collection_context = (PulpAnsibleCollectionRemoteContext,)
 lookup_options = [href_option, name_option]
 remote_options = [
-    click.option("--ca-cert", help=_("a PEM encoded CA certificate")),
-    click.option("--client-cert", help=_("a PEM encoded client certificate")),
-    click.option("--client-key", help=_("a PEM encode private key")),
-    click.option("--tls-validation", help=_("if True, TLS peer validation must be performed")),
-    click.option("--proxy-url", help=_("format: scheme//user:password@host:port")),
-    click.option("--username", help=_("used for authentication when syncing")),
-    click.option("--password"),
-    click.option(
-        "--download-concurrency", type=int, help=_("total number of simultaneous connections")
-    ),
     click.option("--policy", help=_("policy to use when downloading")),
-    click.option(
-        "--total-timeout",
-        type=float,
-        help=_("aiohttp.ClientTimeout.total for download connections"),
-    ),
-    click.option(
-        "--connect-timeout",
-        type=float,
-        help=_("aiohttp.ClientTimeout.connect for download connections"),
-    ),
-    click.option(
-        "--sock-connect-timeout",
-        type=float,
-        help=_("aiohttp.ClientTimeout.sock_connect for download connections"),
-    ),
-    click.option(
-        "--sock-read-timeout",
-        type=float,
-        help=_("aiohttp.ClientTimeout.sock_read for download connections"),
-    ),
-    click.option("--rate-limit", type=int, help=_("limit download rate in requests per second")),
 ]
 collection_options = [
-    click.option(
+    pulp_option(
         "--requirements-file",
         callback=_requirements_callback,
         type=click.File(),
         help=_("Collections only: a Collection requirements yaml"),
+        allowed_with_contexts=collection_context,
     ),
-    click.option(
+    pulp_option(
         "--requirements",
         callback=_requirements_callback,
         help=_("Collections only: a string of a requirements yaml"),
+        allowed_with_contexts=collection_context,
     ),
-    click.option(
+    pulp_option(
         "--auth-url",
         callback=_requirements_callback,
         help=_("Collections only: URL to receive a session token"),
+        allowed_with_contexts=collection_context,
     ),
-    click.option(
+    pulp_option(
         "--token",
         callback=_requirements_callback,
         help=_("Collections only: token key use for authentication"),
+        allowed_with_contexts=collection_context,
     ),
 ]
 ansible_remote_options = remote_options + collection_options
-create_options = [
-    click.option("--name", required=True),
-    click.option("--url", required=True),
-] + ansible_remote_options
-update_options = (
-    lookup_options + [click.option("--url", help=_("new url"))] + ansible_remote_options
-)
+create_options = common_remote_create_options + remote_options + ansible_remote_options
+update_options = common_remote_update_options + remote_options + ansible_remote_options
 
 remote.add_command(list_command(decorators=[label_select_option]))
 remote.add_command(show_command(decorators=lookup_options))
 remote.add_command(destroy_command(decorators=lookup_options))
 remote.add_command(create_command(decorators=create_options))
-remote.add_command(update_command(decorators=update_options))
+remote.add_command(update_command(decorators=lookup_options + update_options))
 remote.add_command(label_command())
