@@ -1,17 +1,18 @@
 # copyright (c) 2020, Matthias Dellweg
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-import gettext
 import json
 import os
-import uuid
-from typing import Any, Callable, Dict, List, Optional
-from urllib.parse import urlencode, urljoin
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from urllib.parse import urljoin
 
 import requests
 import urllib3
 
-_ = gettext.gettext
+from pulpcore.cli.common.i18n import get_translation
+
+translation = get_translation(__name__)
+_ = translation.gettext
 
 SAFE_METHODS = ["GET", "HEAD", "OPTIONS"]
 
@@ -33,8 +34,10 @@ class OpenAPI:
         refresh_cache: bool = False,
         safe_calls_only: bool = False,
         debug_callback: Optional[Callable[[int, str], Any]] = None,
+        user_agent: Optional[str] = None,
     ):
         if not validate_certs:
+            # types-urllib3 does not cover that function
             urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
         self.debug_callback: Callable[[int, str], Any] = debug_callback or (lambda i, x: None)
@@ -42,27 +45,36 @@ class OpenAPI:
         self.doc_path: str = doc_path
         self.safe_calls_only: bool = safe_calls_only
 
-        headers = {
-            "Content-Type": "application/json",
-            "Accept": "application/json",
-        }
         self._session: requests.Session = requests.session()
         if username and password:
             if cert or key:
-                raise OpenAPIError("Cannot use both username/password and cert auth.")
+                raise OpenAPIError(_("Cannot use both username/password and cert auth."))
             self._session.auth = (username, password)
         elif username:
-            raise OpenAPIError("Password is required if username is set.")
+            raise OpenAPIError(_("Password is required if username is set."))
         elif password:
-            raise OpenAPIError("Username is required if password is set.")
+            raise OpenAPIError(_("Username is required if password is set."))
         elif cert and key:
             self._session.cert = (cert, key)
         elif cert:
             self._session.cert = cert
         elif key:
-            raise OpenAPIError("Cert is required if key is set.")
+            raise OpenAPIError(_("Cert is required if key is set."))
+        headers = {
+            "User-Agent": user_agent or "Pulp-CLI openapi parser",
+            "Accept": "application/json",
+        }
         self._session.headers.update(headers)
-        self._session.verify = validate_certs
+        self._session.max_redirects = 0
+
+        verify: Optional[Union[bool, str]] = (
+            os.environ.get("PULP_CA_BUNDLE") if validate_certs is not False else False
+        )
+        session_settings = self._session.merge_environment_settings(  # type:ignore
+            base_url, {}, None, verify, None
+        )
+        self._session.verify = session_settings["verify"]
+        self._session.proxies = session_settings["proxies"]
 
         self.load_api(refresh_cache=refresh_cache)
 
@@ -72,8 +84,7 @@ class OpenAPI:
         apidoc_cache: str = os.path.join(
             os.path.expanduser(xdg_cache_home),
             "squeezer",
-            self.base_url.replace(":", "_").replace("/", "_"),
-            "api.json",
+            (self.base_url + "_" + self.doc_path).replace(":", "_").replace("/", "_") + "api.json",
         )
         try:
             if refresh_cache:
@@ -95,7 +106,7 @@ class OpenAPI:
         if self.api_spec.get("openapi", "").startswith("3."):
             self.openapi_version: int = 3
         else:
-            raise OpenAPIError("Unknown schema version")
+            raise OpenAPIError(_("Unknown schema version"))
         self.operations: Dict[str, Any] = {
             method_entry["operationId"]: (method, path)
             for path, path_entry in self.api_spec["paths"].items()
@@ -139,77 +150,63 @@ class OpenAPI:
             item["name"] for item in param_spec.values() if item.get("required", False)
         ]
         if any(remaining_required):
-            raise OpenAPIError(
-                "Required parameters [{0}] missing for {1}.".format(
-                    ", ".join(remaining_required), param_type
+            raise RuntimeError(
+                _("Required parameters [{required}] missing for {param_type}.").format(
+                    required=", ".join(remaining_required), param_type=param_type
                 )
             )
         return result
 
-    def render_body(
+    def render_request(
         self,
         path_spec: Dict[str, Any],
-        method_spec: Dict[str, Any],
+        method: str,
+        url: str,
+        params: Dict[str, Any],
         headers: Dict[str, str],
         body: Optional[Dict[str, Any]] = None,
         uploads: Optional[Dict[str, bytes]] = None,
-    ) -> Optional[bytes]:
-        if not (body or uploads):
-            return None
-        content_types: List[str] = list(method_spec["requestBody"]["content"].keys())
+    ) -> requests.PreparedRequest:
+        method_spec = path_spec[method]
+        try:
+            content_types: List[str] = (
+                list(method_spec["requestBody"]["content"].keys()) if body or uploads else []
+            )
+        except KeyError:
+            raise OpenAPIError(_("This operation does not expect a request body."))
+
+        data: Optional[Dict[str, Any]] = None
+        json: Optional[Dict[str, Any]] = None
+        files: Optional[List[Tuple[str, Tuple[str, bytes, str]]]] = None
+
         if uploads:
-            body = body or {}
+            data = body or {}
             if any(
                 (content_type.startswith("multipart/form-data") for content_type in content_types)
             ):
-                boundary: str = uuid.uuid4().hex
-                part_boundary: bytes = b"--" + str.encode(boundary)
-
-                form: List[bytes] = []
-                for key, value in body.items():
-                    b_key: bytes = str.encode(key)
-                    form.extend(
-                        [
-                            part_boundary,
-                            b'Content-Disposition: form-data; name="%s"' % b_key,
-                            b"",
-                            str.encode(value),
-                        ]
-                    )
-                for key, file_data in uploads.items():
-                    b_key = str.encode(key)
-                    form.extend(
-                        [
-                            part_boundary,
-                            b'Content-Disposition: file; name="%s"; filename="%s"' % (b_key, b_key),
-                            b"Content-Type: application/octet-stream",
-                            b"",
-                            file_data,
-                        ]
-                    )
-                form.append(part_boundary + b"--")
-                data = b"\r\n".join(form)
-                headers["Content-Type"] = "multipart/form-data; boundary={boundary}".format(
-                    boundary=boundary
-                )
+                files = [
+                    (key, (key, file_data, "application/octet-stream"))
+                    for key, file_data in uploads.items()
+                ]
             else:
-                raise OpenAPIError("No suitable content type for file upload specified.")
+                raise OpenAPIError(_("No suitable content type for file upload specified."))
         elif body:
             if any((content_type.startswith("application/json") for content_type in content_types)):
-                data = str.encode(json.dumps(body))
-                headers["Content-Type"] = "application/json"
+                json = body
             elif any(
                 (
                     content_type.startswith("application/x-www-form-urlencoded")
                     for content_type in content_types
                 )
             ):
-                data = str.encode(urlencode(body))
-                headers["Content-Type"] = "application/x-www-form-urlencoded"
+                data = body
             else:
-                raise OpenAPIError("No suitable content type for request specified.")
-        headers["Content-Length"] = str(len(data))
-        return data
+                raise OpenAPIError(_("No suitable content type for request specified."))
+        return self._session.prepare_request(
+            requests.Request(
+                method, url, params=params, headers=headers, data=data, json=json, files=files
+            )
+        )
 
     def parse_response(self, method_spec: Dict[str, Any], response: requests.Response) -> Any:
         if response.status_code == 204:
@@ -219,7 +216,15 @@ class OpenAPI:
             response_spec = method_spec["responses"][str(response.status_code)]
         except KeyError:
             # Fallback 201 -> 200
-            response_spec = method_spec["responses"][str(100 * int(response.status_code / 100))]
+            try:
+                response_spec = method_spec["responses"][str(100 * int(response.status_code / 100))]
+            except KeyError:
+                raise OpenAPIError(
+                    _("Unexpected response '{code}' (expected '{expected}').").format(
+                        code=response.status_code,
+                        expected=(", ").join(method_spec["responses"].keys()),
+                    )
+                )
         if "application/json" in response_spec["content"]:
             return response.json()
         return None
@@ -241,43 +246,47 @@ class OpenAPI:
             parameters = parameters.copy()
 
         if any(self.extract_params("cookie", path_spec, method_spec, parameters)):
-            raise NotImplementedError("Cookie parameters are not implemented.")
+            raise NotImplementedError(_("Cookie parameters are not implemented."))
 
         headers = self.extract_params("header", path_spec, method_spec, parameters)
 
         for name, value in self.extract_params("path", path_spec, method_spec, parameters).items():
             path = path.replace("{" + name + "}", value)
 
-        query_string = urlencode(
-            self.extract_params("query", path_spec, method_spec, parameters), doseq=True
-        )
+        query_params = self.extract_params("query", path_spec, method_spec, parameters)
 
         if any(parameters):
             raise OpenAPIError(
-                "Parameter [{names}] not available for {operation_id}.".format(
+                _("Parameter [{names}] not available for {operation_id}.").format(
                     names=", ".join(parameters.keys()), operation_id=operation_id
                 )
             )
         url = urljoin(self.base_url, path)
-        if query_string:
-            url += "?" + query_string
 
-        data: Optional[bytes] = self.render_body(path_spec, method_spec, headers, body, uploads)
+        request: requests.PreparedRequest = self.render_request(
+            path_spec, method, url, query_params, headers, body, uploads
+        )
 
-        self.debug_callback(1, f"{method} {url}")
-        for key, value in headers.items():
+        self.debug_callback(1, f"{method} {request.url}")
+        for key, value in request.headers.items():
             self.debug_callback(2, f"  {key}: {value}")
-        if data:
-            self.debug_callback(2, f"{data!r}")
+        if request.body is not None:
+            self.debug_callback(2, f"{request.body!r}")
         if self.safe_calls_only and method.upper() not in SAFE_METHODS:
-            raise OpenAPIError("Call aborted due to safe mode")
+            raise OpenAPIError(_("Call aborted due to safe mode"))
         try:
-            response: requests.Response = self._session.request(
-                method, url, data=data, headers=headers
-            )
+            response: requests.Response = self._session.send(request)
         except requests.ConnectionError as e:
             raise OpenAPIError(str(e))
-        self.debug_callback(1, f"Response: {response.status_code}")
+        except requests.exceptions.TooManyRedirects as e:
+            raise OpenAPIError(
+                _("Received redirect to '{url}'. Please check your CLI configuration.").format(
+                    url=e.response.headers["location"]
+                )
+            )
+        self.debug_callback(
+            1, _("Response: {status_code}").format(status_code=response.status_code)
+        )
         if response.text:
             self.debug_callback(3, f"{response.text}")
         response.raise_for_status()
