@@ -1,4 +1,3 @@
-import gettext
 from typing import Optional, Union, cast
 
 import click
@@ -11,44 +10,38 @@ from pulpcore.cli.common.context import (
     pass_pulp_context,
 )
 from pulpcore.cli.common.generic import (
+    base_path_contains_option,
+    base_path_option,
     create_command,
     destroy_command,
     href_option,
+    label_command,
+    label_select_option,
     list_command,
     name_option,
+    resource_option,
     show_command,
 )
+from pulpcore.cli.common.i18n import get_translation
 from pulpcore.cli.container.context import (
     PulpContainerDistributionContext,
     PulpContainerPushRepositoryContext,
     PulpContainerRepositoryContext,
 )
 
-_ = gettext.gettext
+translation = get_translation(__name__)
+_ = translation.gettext
 
 
-def _repository_callback(
-    ctx: click.Context, param: click.Parameter, value: Optional[str]
-) -> Union[None, str, PulpEntityContext]:
-    # Pass None and "" verbatim
-    if value:
-        pulp_ctx: PulpContext = ctx.find_object(PulpContext)
-        entity_ctx = ctx.find_object(PulpEntityContext)
-        if entity_ctx.meta.get("repository_type") == "container":
-            return PulpContainerRepositoryContext(pulp_ctx, entity={"name": value})
-        elif entity_ctx.meta.get("repository_type") == "push":
-            return PulpContainerPushRepositoryContext(pulp_ctx, entity={"name": value})
-        else:
-            raise NotImplementedError()
-    return value
-
-
-def _repository_type_callback(
-    ctx: click.Context, param: click.Parameter, value: Optional[str]
-) -> Optional[str]:
-    entity_ctx = ctx.find_object(PulpEntityContext)
-    entity_ctx.meta["repository_type"] = value
-    return value
+repository_option = resource_option(
+    "--repository",
+    default_plugin="container",
+    default_type="container",
+    context_table={
+        "container:container": PulpContainerRepositoryContext,
+        "container:push": PulpContainerPushRepositoryContext,
+    },
+)
 
 
 @click.group()
@@ -68,48 +61,32 @@ def distribution(ctx: click.Context, pulp_ctx: PulpContext, distribution_type: s
         raise NotImplementedError()
 
 
+filter_options = [label_select_option, base_path_option, base_path_contains_option]
 lookup_options = [href_option, name_option]
 create_options = [
     click.option("--name", required=True),
     click.option("--base-path", required=True),
-    click.option("--repository", callback=_repository_callback),
+    repository_option,
     click.option(
         "--version", type=int, help=_("a repository version number, leave blank for latest")
     ),
-    click.option(
-        "-t",
-        "--repository-type",
-        "repository_type",
-        type=click.Choice(["container", "push"], case_sensitive=False),
-        default="container",
-        is_eager=True,
-        expose_value=False,
-        callback=_repository_type_callback,
-    ),
+    click.option("--private/--public", default=None),
 ]
 
-distribution.add_command(list_command())
+distribution.add_command(list_command(decorators=filter_options))
 distribution.add_command(show_command(decorators=lookup_options))
 distribution.add_command(create_command(decorators=create_options))
 distribution.add_command(destroy_command(decorators=lookup_options))
+distribution.add_command(label_command())
 
 
 @distribution.command()
 @href_option
 @name_option
 @click.option("--base-path")
-@click.option("--repository", callback=_repository_callback)
+@repository_option
 @click.option("--version", type=int, help=_("a repository version number, leave blank for latest"))
-@click.option(
-    "-t",
-    "--repository-type",
-    "repository_type",
-    type=click.Choice(["container", "push"], case_sensitive=False),
-    default="container",
-    is_eager=True,
-    expose_value=False,
-    callback=_repository_type_callback,
-)
+@click.option("--private/--public", default=None)
 @pass_entity_context
 @pass_pulp_context
 def update(
@@ -118,11 +95,14 @@ def update(
     base_path: Optional[str],
     repository: Optional[Union[str, PulpEntityContext]],
     version: Optional[int],
+    private: Optional[bool],
 ) -> None:
     distribution: EntityDefinition = distribution_ctx.entity
     href: str = distribution_ctx.pulp_href
     body: EntityDefinition = {}
 
+    if private is not None:
+        body["private"] = private
     if base_path is not None:
         body["base_path"] = base_path
     if repository is not None:
