@@ -1,11 +1,11 @@
-import gettext
-
 import click
 
 from pulpcore.cli.common.context import PulpContext, PulpRepositoryContext, pass_pulp_context
 from pulpcore.cli.common.generic import list_command
+from pulpcore.cli.common.i18n import get_translation
 
-_ = gettext.gettext
+translation = get_translation(__name__)
+_ = translation.gettext
 
 
 @click.group()
@@ -18,7 +18,6 @@ def repository(ctx: click.Context, pulp_ctx: PulpContext) -> None:
     Please look for the plugin specific repository commands for more detailed actions.
     i.e. 'pulp file repository <...>'
     """
-    pulp_ctx.needs_plugin("core", min_version="3.10.dev")
     ctx.obj = PulpRepositoryContext(pulp_ctx)
 
 
