@@ -2,8 +2,12 @@ import click
 
 from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.common.generic import href_option, list_command, name_option, show_command
+from pulpcore.cli.common.i18n import get_translation
 from pulpcore.cli.core.context import PulpWorkerContext
 
+translation = get_translation(__name__)
+_ = translation.gettext
+
 
 @click.group()
 @pass_pulp_context
