@@ -1,4 +1,3 @@
-import gettext
 from typing import IO, Optional, Union
 
 import click
@@ -9,23 +8,33 @@ from pulpcore.cli.common.context import (
     pass_entity_context,
     pass_pulp_context,
 )
-from pulpcore.cli.common.generic import create_command, href_option, list_command, show_command
+from pulpcore.cli.common.generic import (
+    chunk_size_option,
+    create_command,
+    href_option,
+    list_command,
+    show_command,
+)
+from pulpcore.cli.common.i18n import get_translation
 from pulpcore.cli.core.context import PulpArtifactContext
 from pulpcore.cli.file.context import PulpFileContentContext
 
-_ = gettext.gettext
+translation = get_translation(__name__)
+_ = translation.gettext
 
 
 def _relative_path_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
     if value is not None:
-        entity_ctx: PulpEntityContext = ctx.find_object(PulpEntityContext)
+        entity_ctx = ctx.find_object(PulpEntityContext)
+        assert entity_ctx is not None
         entity_ctx.entity = {"relative_path": value}
     return value
 
 
 def _sha256_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
     if value is not None:
-        entity_ctx: PulpEntityContext = ctx.find_object(PulpEntityContext)
+        entity_ctx = ctx.find_object(PulpEntityContext)
+        assert entity_ctx is not None
         entity_ctx.entity = {"sha256": value}
     return value
 
@@ -35,7 +44,8 @@ def _sha256_artifact_callback(
 ) -> Optional[Union[str, PulpEntityContext]]:
     # Pass None and "" verbatim
     if value:
-        pulp_ctx: PulpContext = ctx.find_object(PulpContext)
+        pulp_ctx = ctx.find_object(PulpContext)
+        assert pulp_ctx is not None
         return PulpArtifactContext(pulp_ctx, entity={"sha256": value})
     return value
 
@@ -88,9 +98,7 @@ content.add_command(create_command(decorators=create_options))
 @content.command()
 @click.option("--relative-path", required=True)
 @click.option("--file", type=click.File("rb"), required=True)
-@click.option(
-    "--chunk-size", default=1000000, type=int, help=_("Chunk size in bytes (default is 1 MB)")
-)
+@chunk_size_option
 @pass_entity_context
 @pass_pulp_context
 def upload(
