@@ -1,5 +1,5 @@
 from pulpcore.cli.common import main
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
+from pulpcore.cli.common.context import PluginRequirement, PulpContext, pass_pulp_context
 from pulpcore.cli.migration.plan import plan
 from pulpcore.cli.migration.pulp2 import pulp2
 
@@ -7,7 +7,7 @@ from pulpcore.cli.migration.pulp2 import pulp2
 @main.group()
 @pass_pulp_context
 def migration(pulp_ctx: PulpContext) -> None:
-    pulp_ctx.needs_plugin("pulp_2to3_migration")
+    pulp_ctx.needs_plugin(PluginRequirement("pulp_2to3_migration"))
 
 
 migration.add_command(plan)
