@@ -6,10 +6,15 @@ from pulpcore.cli.common.generic import (
     destroy_command,
     href_option,
     list_command,
+    load_json_callback,
     show_command,
 )
+from pulpcore.cli.common.i18n import get_translation
 from pulpcore.cli.migration.context import PulpMigrationPlanContext
 
+translation = get_translation(__name__)
+_ = translation.gettext
+
 
 @click.group()
 @pass_pulp_context
@@ -22,19 +27,29 @@ plan.add_command(list_command())
 plan.add_command(show_command(decorators=[href_option]))
 plan.add_command(destroy_command(decorators=[href_option]))
 
-create_options = [click.option("--plan", required=True, help="Migration plan in JSON format")]
+create_options = [
+    click.option(
+        "--plan",
+        required=True,
+        callback=load_json_callback,
+        help=_(
+            "Migration plan in json format. The argument can be prefixed with @ to use a file "
+            "containing the json."
+        ),
+    )
+]
 plan.add_command(create_command(decorators=create_options))
 
 
-@plan.command(help="Run migration plan")
-@click.option("--href", required=True, help="HREF of the plan")
+@plan.command(help=_("Run migration plan"))
+@click.option("--href", required=True, help=_("HREF of the plan"))
 @pass_entity_context
 def run(plan_ctx: PulpMigrationPlanContext, href: str) -> None:
     plan_ctx.run(href)
 
 
-@plan.command(help="Reset Pulp 3 data for plugins specified in the migration plan")
-@click.option("--href", required=True, help="HREF of the plan")
+@plan.command(help=_("Reset Pulp 3 data for plugins specified in the migration plan"))
+@click.option("--href", required=True, help=_("HREF of the plan"))
 @pass_entity_context
 def reset(plan_ctx: PulpMigrationPlanContext, href: str) -> None:
     plan_ctx.reset(href)
